Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(136)

Unified Diff: views/controls/button/image_button.cc

Issue 113443: ChromeCanvas->gfx::Canvas (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « views/controls/button/image_button.h ('k') | views/controls/button/menu_button.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: views/controls/button/image_button.cc
===================================================================
--- views/controls/button/image_button.cc (revision 16147)
+++ views/controls/button/image_button.cc (working copy)
@@ -4,7 +4,7 @@
#include "views/controls/button/image_button.h"
-#include "app/gfx/chrome_canvas.h"
+#include "app/gfx/canvas.h"
#include "app/throb_animation.h"
#include "skia/ext/image_operations.h"
@@ -20,7 +20,7 @@
: CustomButton(listener),
h_alignment_(ALIGN_LEFT),
v_alignment_(ALIGN_TOP) {
// By default, we request that the ChromeCanvas passed to our View::Paint()
// implementation is flipped horizontally so that the button's bitmaps are
// mirrored when the UI directionality is right-to-left.
EnableCanvasFlippingForRTLUI(true);
@@ -49,7 +49,7 @@
return gfx::Size(kDefaultWidth, kDefaultHeight);
}
-void ImageButton::Paint(ChromeCanvas* canvas) {
+void ImageButton::Paint(gfx::Canvas* canvas) {
// Call the base class first to paint any background/borders.
View::Paint(canvas);
« no previous file with comments | « views/controls/button/image_button.h ('k') | views/controls/button/menu_button.h » ('j') | no next file with comments »
@@ -20,7 +20,7 @@
h_alignment_(ALIGN_LEFT),
v_alignment_(ALIGN_TOP) {
- // By default, we request that the ChromeCanvas passed to our View::Paint()
+ // By default, we request that the gfx::Canvas passed to our View::Paint()
// implementation is flipped horizontally so that the button's bitmaps are
// mirrored when the UI directionality is right-to-left.

Powered by Google App Engine
This is Rietveld 408576698